@@ -19,13 +19,15 @@ public:
     QLocale::NumberOptions formattingOptions = QLocale::DefaultNumberOptions;
 };
 
-KNumberModel::KNumberModel(QObject *parent):
-    QAbstractListModel(parent),
-    d(new KNumberModelPrivate)
-{}
+KNumberModel::KNumberModel(QObject *parent)
+    : QAbstractListModel(parent)
+    , d(new KNumberModelPrivate)
+{
+}
 
 KNumberModel::~KNumberModel()
-{}
+{
+}
 
 void KNumberModel::setMinimumValue(qreal minimumValue)
 {
@@ -94,7 +96,7 @@ QLocale::NumberOptions KNumberModel::formattingOptions() const
     return d->formattingOptions;
 }
 
-qreal KNumberModel::value(const QModelIndex &index)  const
+qreal KNumberModel::value(const QModelIndex &index) const
 {
     if (!index.isValid()) {
         return 0.0;
@@ -110,26 +112,25 @@ int KNumberModel::rowCount(const QModelIndex &index) const
     if (d->stepSize == 0) {
         return 1;
     }
-    //1 initial entry (the minimumValue) + the number of valid steps afterwards
+    // 1 initial entry (the minimumValue) + the number of valid steps afterwards
     return 1 + std::max(0, qFloor((d->maximumValue - d->minimumValue) / d->stepSize));
 }
 
 QVariant KNumberModel::data(const QModelIndex &index, int role) const
 {
-    switch(role) {
-        case KNumberModel::DisplayRole: {
-            auto locale = QLocale::system();
-            locale.setNumberOptions(d->formattingOptions);
-            return QVariant(locale.toString(value(index)));
-        }
-        case KNumberModel::ValueRole:
-            return QVariant(value(index));
+    switch (role) {
+    case KNumberModel::DisplayRole: {
+        auto locale = QLocale::system();
+        locale.setNumberOptions(d->formattingOptions);
+        return QVariant(locale.toString(value(index)));
+    }
+    case KNumberModel::ValueRole:
+        return QVariant(value(index));
     }
     return QVariant();
 }
 
 QHash<int, QByteArray> KNumberModel::roleNames() const
 {
-    return {{KNumberModel::DisplayRole, QByteArrayLiteral("display")},
-                  {KNumberModel::ValueRole, QByteArrayLiteral("value")}};
+    return {{KNumberModel::DisplayRole, QByteArrayLiteral("display")}, {KNumberModel::ValueRole, QByteArrayLiteral("value")}};
 }
